Class “dot”
dot.RdThe dot object is defined so that idiom like .[x,y] returns the
commutator, that is, (x*y-y*x)/2. The factor of 2 ensures that
.[x,y] == x %X% y.
The dot object is generated by running script inst/dot.Rmd,
which includes some further discussion and technical documentation,
and creates file dot.rda which resides in the data/
directory.
Usage
# S4 method for class 'dot,clifford,ANY'
x[i, j]
# S4 method for class 'dot,clifford,ANY,ANY'
x[i, j, drop]Arguments
- x
An object of class
dot(typically the pre-built object.)- i, j
Elements to commute
- drop
Logical; passed to
drop()in the default method