Learn R Programming

clifford (version 1.2-0-2)

dot-class: Class “dot”

Description

The dot object is defined so that idiom like .[x,y] returns the commutator, that is, (x*y-y*x)/2. The factor of 2 ensures that .[x,y] == x %X% y.

The dot object is generated by running script inst/dot.Rmd, which includes some further discussion and technical documentation, and creates file dot.rda which resides in the data/ directory.

Usage

# S4 method for dot,clifford,ANY
[(x, i, j)
# S4 method for dot,clifford,ANY,ANY
[(x, i, j, drop)

Value

Always returns an object of the same class as xy.

Arguments

x

An object of class dot (typically the pre-built object .)

i, j

Elements to commute

drop

Logical; passed to drop() in the default method

Author

Robin K. S. Hankin

Examples

Run this code
x <- rcliff()
y <- rcliff()
z <- rcliff()

.[x,.[y,z]] + .[y,.[z,x]] + .[z,.[x,y]]  # Jacobi identity


Run the code above in your browser using DataLab