minus: Take the negative of a vector

minusR Documentation

Take the negative of a vector

Description

Very simple function that takes the negative of a vector.

Usage

minus(x)

Arguments

x

Clifford object

Details

This trivial function is here so that idiom such as

coeffs(z)[gradesminus(z)%%2 != 0] %<>% minus

works as intended (this taken from Conj.clifford()). Most of the functions in R/involutions.R use minus().

Value

Returns a clifford object

Author(s)

Robin K. S. Hankin

See Also

involution

Examples


x <- rcliff()
minus(x)


clifford documentation built on July 5, 2026, 5:07 p.m.