| magnitude | R Documentation |
Following Perwass, the magnitude of a multivector is defined as
\left|\left|A\right|\right| = \sqrt{A\ast A}
Where A\ast A denotes the Euclidean scalar product
eucprod().
## S3 method for class 'clifford'
Mod(z)
z |
Clifford objects |
For any multivector A, the Euclidean scalar product A\ast
A is never negative, so the square root is always defined.
The function body of Mod.clifford() is
sqrt(abs(eucprod(z))); the abs() is needed to avoid
numerical roundoff errors in eucprod() giving a negative value.
If you want the square, \left|\left|A\right|\right|^2 and
not \left|\left|A\right|\right|, it is faster and more
accurate to use eucprod(A) [rather than Mod(A)^2], because
this avoids a needless square root.
There is a nice example of scalar product at rcliff.Rd.
Robin K. S. Hankin
Ops.clifford,
Conj,
rcliff
Mod(rcliff())
# Perwass, p68, asserts that if A is a k-blade, then (in his notation)
# AA == A*A.
# In package idiom, A*A == A %star% A:
A <- rcliff()
Mod(A*A - A %star% A) # meh
A <- rblade()
Mod(A*A - A %star% A) # should be small
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.