Learn R Programming

clifford (version 1.2-0)

magnitude: Magnitude of a clifford object

Description

Following Perwass, the magnitude of a multivector is defined as

$$\left|\left|A\right|\right| = \sqrt{A\ast A}$$

Where \(A\ast A\) denotes the Euclidean scalar product eucprod().

Usage

# S3 method for clifford
Mod(z)

Arguments

z

Clifford objects

Author

Robin K. S. Hankin

Details

For any multivector \(A\), the Euclidean scalar product \(A\ast A\) is never negative, so the square root is always defined.

The function body of Mod.clifford() is sqrt(abs(eucprod(z))); the abs() is needed to avoid numerical roundoff errors in eucprod() giving a negative value.

See Also

Ops.clifford, Conj, rcliff

Examples

Run this code


Mod(rcliff())


# Perwass, p68, asserts that if A is a k-blade, then (in his notation)
# AA == A*A.

# In package idiom, A*A == A %star% A:

A <- rcliff()          
Mod(A*A - A %star% A)  # meh

A <- rblade()
Mod(A*A - A %star% A)  # should be small

Run the code above in your browser using DataLab