Learn R Programming

clifford (version 1.0-2)

magnitude: Magnitude of a clifford object

Description

Following Perwass, the magnitude of a multivector is defined as

$$\left|\left|A\right|\right| = \sqrt{A\ast A}$$

Where \(A\ast A\) denotes the Euclidean scalar product eucprod(). Recall that the Euclidean scalar product is never negative.

Usage

# S3 method for clifford
Mod(z)

Arguments

z

Clifford objects

See Also

Ops.clifford, Conj, rcliff

Examples

Run this code
# NOT RUN {

Mod(rcliff())


# Perwass, p68, asserts that if A is a k-blade, then (in his notation)
# AA == A*A.

# In package idiom, A*A == A %star% A:

A <- rcliff()          
Mod(A*A - A %star% A)  # meh

A <- rblade()
Mod(A*A - A %star% A)  # should be small



# }

Run the code above in your browser using DataLab