| minus | R Documentation |
Very simple function that takes the negative of a vector.
minus(x)
x |
Clifford object |
This trivial function is here so that idiom such as
coeffs(z)[gradesminus(z)%%2 != 0] %<>% minus
works as intended (this taken from Conj.clifford()). Most of the
functions in R/involutions.R use minus().
Returns a clifford object
Robin K. S. Hankin
involution
x <- rcliff()
minus(x)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.