Take the negative of a vector
minus.RdVery simple function that takes the negative of a vector.
Details
This trivial function is here so that idiom such as
coeffs(z)[gradesminus(z)%%2 != 0] %<>% minusworks as intended (this taken from Conj.clifford()). Most of the
functions in R/involutions.R use minus().
Examples
x <- rcliff()
minus(x)
#> Element of a Clifford algebra, equal to
#> - 6 + 5e_135 - 2e_145 + 3e_2345 + 9e_6 - 5e_16 + 2e_246 - 8e_456 + 6e_3456