Learn R Programming

clifford (version 1.0-2)

signature: The signature of the Clifford algebra

Description

Getting and setting the signature of the Clifford algebra

Usage

signature(s)
is_ok_sig(s)
mymax(s)

Arguments

s

Integer, specifying number of positive elements on the diagonal of the quadratic form

Details

The function is modelled on lorentz::sol() which gets and sets the speed of light.

Clifford algebras require a bilinear form on \(R^n\) \(\left<\cdot,\cdot\right>\), usually written

$$\left<{\mathbf x},{\mathbf x}\right>=x_1^2+x_2^2+\cdots +x_p^2-x_{p+1}^2-\cdots -x_{p+q}^2 $$

where \(p+q=n\). With this quadratic form the vector space is denoted \(R^{p,q}\), and we say that \(p\) is the signature of the bilinear form \(\left<\cdot,\cdot\right>\). This gives rise to the Clifford algebra \(C_{p,q}\).

If the quadratic form is positive-definite, package idiom is to use the default special value \(p=0\) (which means that zero entries on the main diagonal are negative).

Specifying a negative value for \(p\) sets the quadratic form to be identically zero, reducing the geometric product to the exterior wedge product and thus a Grassman algebra. But use the wedge package for this, which is much more efficient and uses nicer idiom.

Function is_ok_sig() is a helper function that checks for a proper signature.

Function mymax() is a helper function that avoids warnings from max() when given an empty argument.

Examples

Run this code
# NOT RUN {


e1 <- clifford(list(1),1)
e2 <- clifford(list(2),1)


signature()


e1*e1
e2*e2

signature(1)
e1*e1
e2*e2   #note sign

signature(Inf)
e2*e2

# }

Run the code above in your browser using DataLab